/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Radha Kulkarni <radha@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or 
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/**
 * An interface to individual entries in session history. Each 
 * document or frame will have a nsIHistoryEntry associated with 
 * it. nsIHistoryEntry provides access to information like URI, 
 * title and frame traversal status for that document.
 * This interface is accessible from javascript.
 * 
 * @status FROZEN
 */
#include "nsISupports.idl"

interface nsIURI;

[scriptable, uuid(A41661D4-1417-11D5-9882-00C04FA02F40)]
interface nsIHistoryEntry : nsISupports 
{

/** 
 * A readonly property that returns the URI
 * of the current entry. The object returned is
 * of type nsIURI
 */
readonly attribute nsIURI URI;

/** 
 * A readonly property that returns the title
 * of the current entry.  The object returned
 * is a encoded string
 */
readonly attribute wstring title;

/** 
 * A readonly property that returns a boolean
 * flag which indicates if the entry was created as a 
 * result of a subframe navigation. This flag will be
 * 'false' when a frameset page is visited for
 * the first time. This flag will be 'true' for all
 * history entries created as a result of a subframe
 * navigation.
 */
readonly attribute boolean isSubFrame;

};


%{ C++
// {A41661D5-1417-11D5-9882-00C04FA02F40}
#define NS_HISTORYENTRY_CID \
{0xa41661d5, 0x1417, 0x11d5, {0x98, 0x82, 0x0, 0xc0, 0x4f, 0xa0, 0x2f, 0x40}}

#define NS_HISTORYENTRY_CONTRACTID \
    "@mozilla.org/browser/history-entry;1"

%}

